@@ -294,6 +294,8 @@ abstract class Assert
     /**
      * Asserts that a haystack contains only values of type array.
      *
+     * @phpstan-assert iterable<array<mixed>> $haystack
+     *
      * @param iterable<mixed> $haystack
      *
      * @throws ExpectationFailedException
@@ -312,6 +314,8 @@ abstract class Assert
     /**
      * Asserts that a haystack contains only values of type bool.
      *
+     * @phpstan-assert iterable<bool> $haystack
+     *
      * @param iterable<mixed> $haystack
      *
      * @throws ExpectationFailedException
@@ -330,6 +334,8 @@ abstract class Assert
     /**
      * Asserts that a haystack contains only values of type callable.
      *
+     * @phpstan-assert iterable<callable> $haystack
+     *
      * @param iterable<mixed> $haystack
      *
      * @throws ExpectationFailedException
@@ -348,6 +354,8 @@ abstract class Assert
     /**
      * Asserts that a haystack contains only values of type float.
      *
+     * @phpstan-assert iterable<float> $haystack
+     *
      * @param iterable<mixed> $haystack
      *
      * @throws ExpectationFailedException
@@ -366,6 +374,8 @@ abstract class Assert
     /**
      * Asserts that a haystack contains only values of type int.
      *
+     * @phpstan-assert iterable<int> $haystack
+     *
      * @param iterable<mixed> $haystack
      *
      * @throws ExpectationFailedException
@@ -384,6 +394,8 @@ abstract class Assert
     /**
      * Asserts that a haystack contains only values of type iterable.
      *
+     * @phpstan-assert iterable<iterable<mixed>> $haystack
+     *
      * @param iterable<mixed> $haystack
      *
      * @throws ExpectationFailedException
@@ -402,6 +414,8 @@ abstract class Assert
     /**
      * Asserts that a haystack contains only values of type null.
      *
+     * @phpstan-assert iterable<null> $haystack
+     *
      * @param iterable<mixed> $haystack
      *
      * @throws ExpectationFailedException
@@ -420,6 +434,8 @@ abstract class Assert
     /**
      * Asserts that a haystack contains only values of type numeric.
      *
+     * @phpstan-assert iterable<numeric> $haystack
+     *
      * @param iterable<mixed> $haystack
      *
      * @throws ExpectationFailedException
@@ -438,6 +454,8 @@ abstract class Assert
     /**
      * Asserts that a haystack contains only values of type object.
      *
+     * @phpstan-assert iterable<object> $haystack
+     *
      * @param iterable<mixed> $haystack
      *
      * @throws ExpectationFailedException
@@ -456,6 +474,8 @@ abstract class Assert
     /**
      * Asserts that a haystack contains only values of type resource.
      *
+     * @phpstan-assert iterable<resource> $haystack
+     *
      * @param iterable<mixed> $haystack
      *
      * @throws ExpectationFailedException
@@ -474,6 +494,8 @@ abstract class Assert
     /**
      * Asserts that a haystack contains only values of type closed resource.
      *
+     * @phpstan-assert iterable<resource> $haystack
+     *
      * @param iterable<mixed> $haystack
      *
      * @throws ExpectationFailedException
@@ -492,6 +514,8 @@ abstract class Assert
     /**
      * Asserts that a haystack contains only values of type scalar.
      *
+     * @phpstan-assert iterable<scalar> $haystack
+     *
      * @param iterable<mixed> $haystack
      *
      * @throws ExpectationFailedException
@@ -510,6 +534,8 @@ abstract class Assert
     /**
      * Asserts that a haystack contains only values of type string.
      *
+     * @phpstan-assert iterable<string> $haystack
+     *
      * @param iterable<mixed> $haystack
      *
      * @throws ExpectationFailedException
@@ -528,7 +554,11 @@ abstract class Assert
     /**
      * Asserts that a haystack contains only instances of a specified interface or class name.
      *
-     * @param class-string    $className
+     * @template T
+     *
+     * @phpstan-assert iterable<T> $haystack
+     *
+     * @param class-string<T> $className
      * @param iterable<mixed> $haystack
      *
      * @throws Exception
@@ -2652,14 +2682,7 @@ abstract class Assert
         self::assertIsString($actualJson);
         self::assertJson($actualJson, $message);
 
-        $constraintExpected = new JsonMatches(
-            $expectedJson,
-        );
-
-        $constraintActual = new JsonMatches($actualJson);
-
-        self::assertThat($expectedJson, $constraintActual, $message);
-        self::assertThat($actualJson, $constraintExpected, $message);
+        self::assertThat($actualJson, new JsonMatches($expectedJson), $message);
     }
 
     /**
@@ -2683,14 +2706,7 @@ abstract class Assert
         self::assertIsString($actualJson);
         self::assertJson($actualJson, $message);
 
-        $constraintExpected = new JsonMatches(
-            $expectedJson,
-        );
-
-        $constraintActual = new JsonMatches($actualJson);
-
-        self::assertThat($expectedJson, new LogicalNot($constraintActual), $message);
-        self::assertThat($actualJson, new LogicalNot($constraintExpected), $message);
+        self::assertThat($actualJson, self::logicalNot(new JsonMatches($expectedJson)), $message);
     }
 
     /**
