@@ -11,7 +11,7 @@ namespace PHPUnit\TestFixture;
 
 use PHPUnit\Framework\TestCase;
 
-class BeforeClassAndAfterClassTest extends TestCase
+final class BeforeClassAndAfterClassTest extends TestCase
 {
     public static $beforeClassWasRun = 0;
     public static $afterClassWasRun  = 0;
