@@ -9,7 +9,10 @@
  */
 namespace PHPUnit\TestFixture;
 
-class BeforeClassWithOnlyDataProviderTest extends \PHPUnit\Framework\TestCase
+use PHPUnit\Framework\Attributes\DataProvider;
+use PHPUnit\Framework\TestCase;
+
+final class BeforeClassWithOnlyDataProviderTest extends TestCase
 {
     public static $setUpBeforeClassWasCalled;
     public static $beforeClassWasCalled;
@@ -28,20 +31,17 @@ class BeforeClassWithOnlyDataProviderTest extends \PHPUnit\Framework\TestCase
         self::$beforeClassWasCalled = true;
     }
 
+    public static function dummyProvider(): array
+    {
+        return [[1]];
+    }
+
     public static function setUpBeforeClass(): void
     {
         self::$setUpBeforeClassWasCalled = true;
     }
 
-    public function dummyProvider()
-    {
-        return [[1]];
-    }
-
-    /**
-     * @dataProvider dummyProvider
-     * delete annotation to fail test case
-     */
+    #[DataProvider('dummyProvider')]
     public function testDummy(): void
     {
         $this->assertFalse(false);
