@@ -11,10 +11,12 @@ namespace PHPUnit\TestFixture;
 
 use PHPUnit\Framework\TestCase;
 
-class CoverageFunctionParenthesesTest extends TestCase
+final class CoverageFunctionParenthesesTest extends TestCase
 {
     /**
      * @covers ::globalFunction()
+     *
+     * @uses ::globalFunction()
      */
     public function testSomething(): void
     {
