@@ -11,10 +11,12 @@ namespace PHPUnit\TestFixture;
 
 use PHPUnit\Framework\TestCase;
 
-class CoverageFunctionParenthesesWhitespaceTest extends TestCase
+final class CoverageFunctionParenthesesWhitespaceTest extends TestCase
 {
     /**
      * @covers ::globalFunction ( )
+     *
+     * @uses ::globalFunction ( )
      */
     public function testSomething(): void
     {
