@@ -9,13 +9,14 @@
  */
 namespace PHPUnit\TestFixture;
 
+use PHPUnit\Framework\Attributes\CoversFunction;
+use PHPUnit\Framework\Attributes\UsesFunction;
 use PHPUnit\Framework\TestCase;
 
-class CoverageFunctionTest extends TestCase
+#[CoversFunction('globalFunction')]
+#[UsesFunction('globalFunction')]
+final class CoverageFunctionTest extends TestCase
 {
-    /**
-     * @covers ::globalFunction
-     */
     public function testSomething(): void
     {
         globalFunction();
