@@ -11,10 +11,12 @@ namespace PHPUnit\TestFixture;
 
 use PHPUnit\Framework\TestCase;
 
-class CoverageMethodParenthesesTest extends TestCase
+final class CoverageMethodParenthesesTest extends TestCase
 {
     /**
      * @covers \PHPUnit\TestFixture\CoveredClass::publicMethod()
+     *
+     * @uses \PHPUnit\TestFixture\CoveredClass::publicMethod()
      */
     public function testSomething(): void
     {
