@@ -11,10 +11,12 @@ namespace PHPUnit\TestFixture;
 
 use PHPUnit\Framework\TestCase;
 
-class CoverageMethodParenthesesWhitespaceTest extends TestCase
+final class CoverageMethodParenthesesWhitespaceTest extends TestCase
 {
     /**
      * @covers \PHPUnit\TestFixture\CoveredClass::publicMethod ( )
+     *
+     * @uses \PHPUnit\TestFixture\CoveredClass::publicMethod ( )
      */
     public function testSomething(): void
     {
