@@ -11,10 +11,12 @@ namespace PHPUnit\TestFixture;
 
 use PHPUnit\Framework\TestCase;
 
-class CoverageNamespacedFunctionTest extends TestCase
+final class CoverageNamespacedFunctionTest extends TestCase
 {
     /**
      * @covers \PHPUnit\TestFixture\func()
+     *
+     * @uses \PHPUnit\TestFixture\func()
      */
     public function testFunc(): void
     {
