@@ -9,18 +9,17 @@
  */
 namespace PHPUnit\TestFixture;
 
+use PHPUnit\Framework\Attributes\DataProvider;
 use PHPUnit\Framework\TestCase;
 
-class EmptyDataProviderTest extends TestCase
+final class EmptyDataProviderTest extends TestCase
 {
-    public static function providerMethod()
+    public static function providerMethod(): array
     {
         return [];
     }
 
-    /**
-     * @dataProvider providerMethod
-     */
+    #[DataProvider('providerMethod')]
     public function testCase(): void
     {
     }
