@@ -9,12 +9,16 @@
  */
 namespace PHPUnit\TestFixture;
 
+use ArrayIterator;
 use ArrayObject;
+use Generator;
+use Iterator;
+use PHPUnit\Framework\Attributes\DataProvider;
 use PHPUnit\Framework\TestCase;
 
-class MultipleDataProviderTest extends TestCase
+final class MultipleDataProviderTest extends TestCase
 {
-    public static function providerA()
+    public static function providerA(): array
     {
         return [
             ['ok', null, null],
@@ -23,7 +27,7 @@ class MultipleDataProviderTest extends TestCase
         ];
     }
 
-    public static function providerB()
+    public static function providerB(): array
     {
         return [
             [null, 'ok', null],
@@ -32,7 +36,7 @@ class MultipleDataProviderTest extends TestCase
         ];
     }
 
-    public static function providerC()
+    public static function providerC(): array
     {
         return [
             [null, null, 'ok'],
@@ -41,7 +45,7 @@ class MultipleDataProviderTest extends TestCase
         ];
     }
 
-    public static function providerD()
+    public static function providerD(): Generator
     {
         yield ['ok', null, null];
 
@@ -50,7 +54,7 @@ class MultipleDataProviderTest extends TestCase
         yield ['ok', null, null];
     }
 
-    public static function providerE()
+    public static function providerE(): Generator
     {
         yield [null, 'ok', null];
 
@@ -59,7 +63,7 @@ class MultipleDataProviderTest extends TestCase
         yield [null, 'ok', null];
     }
 
-    public static function providerF()
+    public static function providerF(): ArrayIterator|Iterator
     {
         $object = new ArrayObject(
             [
@@ -72,20 +76,16 @@ class MultipleDataProviderTest extends TestCase
         return $object->getIterator();
     }
 
-    /**
-     * @dataProvider providerA
-     * @dataProvider providerB
-     * @dataProvider providerC
-     */
+    #[DataProvider('providerA')]
+    #[DataProvider('providerB')]
+    #[DataProvider('providerC')]
     public function testOne(): void
     {
     }
 
-    /**
-     * @dataProvider providerD
-     * @dataProvider providerE
-     * @dataProvider providerF
-     */
+    #[DataProvider('providerD')]
+    #[DataProvider('providerE')]
+    #[DataProvider('providerF')]
     public function testTwo(): void
     {
     }
