@@ -9,9 +9,12 @@
  */
 namespace PHPUnit\TestFixture;
 
-class VariousIterableDataProviderTest extends AbstractVariousIterableDataProviderTest
+use Generator;
+use PHPUnit\Framework\Attributes\DataProvider;
+
+final class VariousIterableDataProviderTest extends AbstractVariousIterableDataProviderTest
 {
-    public static function asArrayStaticProvider()
+    public static function asArrayStaticProvider(): array
     {
         return [
             ['A'],
@@ -20,7 +23,7 @@ class VariousIterableDataProviderTest extends AbstractVariousIterableDataProvide
         ];
     }
 
-    public static function asIteratorStaticProvider()
+    public static function asIteratorStaticProvider(): Generator
     {
         yield ['D'];
 
@@ -29,7 +32,7 @@ class VariousIterableDataProviderTest extends AbstractVariousIterableDataProvide
         yield ['F'];
     }
 
-    public static function asTraversableStaticProvider()
+    public static function asTraversableStaticProvider(): WrapperIteratorAggregate
     {
         return new WrapperIteratorAggregate([
             ['G'],
@@ -38,7 +41,7 @@ class VariousIterableDataProviderTest extends AbstractVariousIterableDataProvide
         ]);
     }
 
-    public static function asArrayProvider()
+    public static function asArrayProvider(): array
     {
         return [
             ['S'],
@@ -47,7 +50,7 @@ class VariousIterableDataProviderTest extends AbstractVariousIterableDataProvide
         ];
     }
 
-    public static function asIteratorProvider()
+    public static function asIteratorProvider(): Generator
     {
         yield ['V'];
 
@@ -56,7 +59,7 @@ class VariousIterableDataProviderTest extends AbstractVariousIterableDataProvide
         yield ['X'];
     }
 
-    public static function asTraversableProvider()
+    public static function asTraversableProvider(): WrapperIteratorAggregate
     {
         return new WrapperIteratorAggregate([
             ['Y'],
@@ -65,29 +68,23 @@ class VariousIterableDataProviderTest extends AbstractVariousIterableDataProvide
         ]);
     }
 
-    /**
-     * @dataProvider asArrayStaticProvider
-     * @dataProvider asIteratorStaticProvider
-     * @dataProvider asTraversableStaticProvider
-     */
+    #[DataProvider('asArrayStaticProvider')]
+    #[DataProvider('asIteratorStaticProvider')]
+    #[DataProvider('asTraversableStaticProvider')]
     public function testStatic(): void
     {
     }
 
-    /**
-     * @dataProvider asArrayProvider
-     * @dataProvider asIteratorProvider
-     * @dataProvider asTraversableProvider
-     */
+    #[DataProvider('asArrayProvider')]
+    #[DataProvider('asIteratorProvider')]
+    #[DataProvider('asTraversableProvider')]
     public function testNonStatic(): void
     {
     }
 
-    /**
-     * @dataProvider asArrayProviderInParent
-     * @dataProvider asIteratorProviderInParent
-     * @dataProvider asTraversableProviderInParent
-     */
+    #[DataProvider('asArrayProviderInParent')]
+    #[DataProvider('asIteratorProviderInParent')]
+    #[DataProvider('asTraversableProviderInParent')]
     public function testFromParent(): void
     {
     }
