@@ -7,7 +7,9 @@
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
-const TEST_FILES_PATH = __DIR__ . DIRECTORY_SEPARATOR . '_files' . DIRECTORY_SEPARATOR;
+if (!defined('TEST_FILES_PATH')) {
+    define('TEST_FILES_PATH', __DIR__ . DIRECTORY_SEPARATOR . '_files' . DIRECTORY_SEPARATOR);
+}
 
 $composer = file_exists(__DIR__ . '/../vendor/autoload.php');
 $phar     = file_exists(__DIR__ . '/autoload.php');
