@@ -7,11 +7,12 @@
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
+namespace PHPUnit\TestFixture;
+
+use PHPUnit\Framework\Attributes\CoversClass;
 use PHPUnit\Framework\TestCase;
 
-/**
- * @covers NoLogNoCc
- */
+#[CoversClass(NoLogNoCc::class)]
 final class NoLogNoCcTest extends TestCase
 {
     public function testSuccess(): void
