@@ -34,8 +34,7 @@ use PHPUnit\TestFixture\CoverageMethodParenthesesWhitespaceTest;
 use PHPUnit\TestFixture\CoverageMethodTest;
 use PHPUnit\TestFixture\CoverageNamespacedFunctionTest;
 use PHPUnit\TestFixture\CoverageNoneTest;
-use PHPUnit\TestFixture\CoverageTraitMethodTest;
-use PHPUnit\TestFixture\CoverageTraitTest;
+use PHPUnit\TestFixture\CoveredClassUsingCoveredTraitTest;
 use PHPUnit\TestFixture\InterfaceAsTargetWithAttributeTest;
 use PHPUnit\TestFixture\InterfaceTargetTest;
 use PHPUnit\TestFixture\InvalidClassTargetWithAnnotationTest;
@@ -65,7 +64,8 @@ final class CodeCoverageTest extends TestCase
 
             [
                 [
-                    TEST_FILES_PATH . 'CoveredClass.php' => array_merge(range(12, 27), range(29, 46)),
+                    TEST_FILES_PATH . 'CoveredClass.php'       => array_merge(range(12, 29)),
+                    TEST_FILES_PATH . 'CoveredParentClass.php' => array_merge(range(12, 27)),
                 ],
                 CoverageClassTest::class,
                 'testSomething',
@@ -73,7 +73,7 @@ final class CodeCoverageTest extends TestCase
 
             [
                 [
-                    TEST_FILES_PATH . 'CoveredClass.php' => range(31, 35),
+                    TEST_FILES_PATH . 'CoveredClass.php' => range(14, 18),
                 ],
                 CoverageMethodTest::class,
                 'testSomething',
@@ -81,7 +81,7 @@ final class CodeCoverageTest extends TestCase
 
             [
                 [
-                    TEST_FILES_PATH . 'CoveredClass.php' => range(31, 35),
+                    TEST_FILES_PATH . 'CoveredClass.php' => range(14, 18),
                 ],
                 CoverageMethodAnnotationTest::class,
                 'testSomething',
@@ -89,7 +89,7 @@ final class CodeCoverageTest extends TestCase
 
             [
                 [
-                    TEST_FILES_PATH . 'CoveredClass.php' => range(31, 35),
+                    TEST_FILES_PATH . 'CoveredClass.php' => range(14, 18),
                 ],
                 CoverageMethodOneLineAnnotationTest::class,
                 'testSomething',
@@ -97,15 +97,7 @@ final class CodeCoverageTest extends TestCase
 
             [
                 [
-                    TEST_FILES_PATH . 'CoveredFunction.php' => range(10, 12),
-                ],
-                CoverageFunctionTest::class,
-                'testSomething',
-            ],
-
-            [
-                [
-                    TEST_FILES_PATH . 'CoveredClass.php' => range(29, 46),
+                    TEST_FILES_PATH . 'CoveredClass.php' => range(12, 29),
                 ],
                 NamespaceCoverageClassTest::class,
                 'testSomething',
@@ -113,7 +105,7 @@ final class CodeCoverageTest extends TestCase
 
             [
                 [
-                    TEST_FILES_PATH . 'CoveredClass.php' => range(31, 35),
+                    TEST_FILES_PATH . 'CoveredClass.php' => range(14, 18),
                 ],
                 NamespaceCoverageMethodTest::class,
                 'testSomething',
@@ -121,7 +113,8 @@ final class CodeCoverageTest extends TestCase
 
             [
                 [
-                    TEST_FILES_PATH . 'CoveredClass.php' => array_merge(range(43, 45), range(37, 41), range(31, 35), range(24, 26), range(19, 22), range(14, 17)),
+                    TEST_FILES_PATH . 'CoveredClass.php'       => array_merge(range(14, 18), range(20, 24), range(26, 28)),
+                    TEST_FILES_PATH . 'CoveredParentClass.php' => array_merge(range(14, 17), range(19, 22), range(24, 26)),
                 ],
                 NamespaceCoverageCoversClassTest::class,
                 'testSomething',
@@ -129,12 +122,37 @@ final class CodeCoverageTest extends TestCase
 
             [
                 [
-                    TEST_FILES_PATH . 'CoveredClass.php' => range(31, 35),
+                    TEST_FILES_PATH . 'CoveredClass.php' => range(14, 18),
                 ],
                 NamespaceCoverageCoversClassPublicTest::class,
                 'testSomething',
             ],
 
+            [
+                [
+                    TEST_FILES_PATH . 'CoveredClassUsingCoveredTrait.php' => range(12, 27),
+                    TEST_FILES_PATH . 'CoveredTrait.php'                  => range(12, 18),
+                ],
+                CoveredClassUsingCoveredTraitTest::class,
+                'testSomething',
+            ],
+
+            [
+                [
+                    TEST_FILES_PATH . 'CoveredClass.php' => range(14, 18),
+                ],
+                CoverageMethodParenthesesTest::class,
+                'testSomething',
+            ],
+
+            [
+                [
+                    TEST_FILES_PATH . 'CoveredClass.php' => range(14, 18),
+                ],
+                CoverageMethodParenthesesWhitespaceTest::class,
+                'testSomething',
+            ],
+
             [
                 false,
                 CoverageClassNothingTest::class,
@@ -149,7 +167,7 @@ final class CodeCoverageTest extends TestCase
 
             [
                 [
-                    TEST_FILES_PATH . 'CoveredClass.php' => range(31, 35),
+                    TEST_FILES_PATH . 'CoveredClass.php' => range(14, 18),
                 ],
                 CoverageCoversOverridesCoversNothingTest::class,
                 'testSomething',
@@ -161,6 +179,14 @@ final class CodeCoverageTest extends TestCase
                 'testSomething',
             ],
 
+            [
+                [
+                    TEST_FILES_PATH . 'CoveredFunction.php' => range(10, 12),
+                ],
+                CoverageFunctionTest::class,
+                'testSomething',
+            ],
+
             [
                 [
                     TEST_FILES_PATH . 'CoveredFunction.php' => range(10, 12),
@@ -177,22 +203,6 @@ final class CodeCoverageTest extends TestCase
                 'testSomething',
             ],
 
-            [
-                [
-                    TEST_FILES_PATH . 'CoveredClass.php' => range(31, 35),
-                ],
-                CoverageMethodParenthesesTest::class,
-                'testSomething',
-            ],
-
-            [
-                [
-                    TEST_FILES_PATH . 'CoveredClass.php' => range(31, 35),
-                ],
-                CoverageMethodParenthesesWhitespaceTest::class,
-                'testSomething',
-            ],
-
             [
                 [
                     TEST_FILES_PATH . 'NamespaceCoveredFunction.php' => range(12, 15),
@@ -208,22 +218,6 @@ final class CodeCoverageTest extends TestCase
                 Test3194::class,
                 'testOne',
             ],
-
-            [
-                [
-                    TEST_FILES_PATH . 'CoveredTrait.php' => range(12, 18),
-                ],
-                CoverageTraitTest::class,
-                'testSomething',
-            ],
-
-            [
-                [
-                    TEST_FILES_PATH . 'CoveredTrait.php' => range(14, 17),
-                ],
-                CoverageTraitMethodTest::class,
-                'testSomething',
-            ],
         ];
     }
 
@@ -238,7 +232,8 @@ final class CodeCoverageTest extends TestCase
 
             [
                 [
-                    TEST_FILES_PATH . 'CoveredClass.php' => array_merge(range(12, 27), range(29, 46)),
+                    TEST_FILES_PATH . 'CoveredClass.php'       => array_merge(range(12, 29)),
+                    TEST_FILES_PATH . 'CoveredParentClass.php' => array_merge(range(12, 27)),
                 ],
                 CoverageClassTest::class,
                 'testSomething',
@@ -246,7 +241,7 @@ final class CodeCoverageTest extends TestCase
 
             [
                 [
-                    TEST_FILES_PATH . 'CoveredClass.php' => range(31, 35),
+                    TEST_FILES_PATH . 'CoveredClass.php' => range(14, 18),
                 ],
                 CoverageMethodTest::class,
                 'testSomething',
@@ -254,12 +249,54 @@ final class CodeCoverageTest extends TestCase
 
             [
                 [
-                    TEST_FILES_PATH . 'CoveredClass.php' => range(31, 35),
+                    TEST_FILES_PATH . 'CoveredClass.php' => range(14, 18),
                 ],
                 CoverageMethodAnnotationTest::class,
                 'testSomething',
             ],
 
+            [
+                [
+                    TEST_FILES_PATH . 'CoveredClass.php' => range(12, 29),
+                ],
+                NamespaceCoverageClassTest::class,
+                'testSomething',
+            ],
+
+            [
+                [
+                    TEST_FILES_PATH . 'CoveredClass.php' => range(14, 18),
+                ],
+                NamespaceCoverageMethodTest::class,
+                'testSomething',
+            ],
+
+            [
+                [
+                    TEST_FILES_PATH . 'CoveredClass.php'       => array_merge(range(14, 18), range(20, 24), range(26, 28)),
+                    TEST_FILES_PATH . 'CoveredParentClass.php' => array_merge(range(14, 17), range(19, 22), range(24, 26)),
+                ],
+                NamespaceCoverageCoversClassTest::class,
+                'testSomething',
+            ],
+
+            [
+                [
+                    TEST_FILES_PATH . 'CoveredClass.php' => range(14, 18),
+                ],
+                NamespaceCoverageCoversClassPublicTest::class,
+                'testSomething',
+            ],
+
+            [
+                [
+                    TEST_FILES_PATH . 'CoveredClassUsingCoveredTrait.php' => range(12, 27),
+                    TEST_FILES_PATH . 'CoveredTrait.php'                  => range(12, 18),
+                ],
+                CoveredClassUsingCoveredTraitTest::class,
+                'testSomething',
+            ],
+
             [
                 [
                     TEST_FILES_PATH . 'CoveredFunction.php' => range(10, 12),
@@ -268,38 +305,6 @@ final class CodeCoverageTest extends TestCase
                 'testSomething',
             ],
 
-            [
-                [
-                    TEST_FILES_PATH . 'CoveredClass.php' => range(29, 46),
-                ],
-                NamespaceCoverageClassTest::class,
-                'testSomething',
-            ],
-
-            [
-                [
-                    TEST_FILES_PATH . 'CoveredClass.php' => range(31, 35),
-                ],
-                NamespaceCoverageMethodTest::class,
-                'testSomething',
-            ],
-
-            [
-                [
-                    TEST_FILES_PATH . 'CoveredClass.php' => array_merge(range(43, 45), range(37, 41), range(31, 35), range(24, 26), range(19, 22), range(14, 17)),
-                ],
-                NamespaceCoverageCoversClassTest::class,
-                'testSomething',
-            ],
-
-            [
-                [
-                    TEST_FILES_PATH . 'CoveredClass.php' => range(31, 35),
-                ],
-                NamespaceCoverageCoversClassPublicTest::class,
-                'testSomething',
-            ],
-
             [
                 [
                     TEST_FILES_PATH . 'CoveredFunction.php' => range(10, 12),
@@ -318,7 +323,7 @@ final class CodeCoverageTest extends TestCase
 
             [
                 [
-                    TEST_FILES_PATH . 'CoveredClass.php' => range(31, 35),
+                    TEST_FILES_PATH . 'CoveredClass.php' => range(14, 18),
                 ],
                 CoverageMethodParenthesesTest::class,
                 'testSomething',
@@ -326,7 +331,7 @@ final class CodeCoverageTest extends TestCase
 
             [
                 [
-                    TEST_FILES_PATH . 'CoveredClass.php' => range(31, 35),
+                    TEST_FILES_PATH . 'CoveredClass.php' => range(14, 18),
                 ],
                 CoverageMethodParenthesesWhitespaceTest::class,
                 'testSomething',
@@ -339,22 +344,6 @@ final class CodeCoverageTest extends TestCase
                 CoverageNamespacedFunctionTest::class,
                 'testFunc',
             ],
-
-            [
-                [
-                    TEST_FILES_PATH . 'CoveredTrait.php' => range(12, 18),
-                ],
-                CoverageTraitTest::class,
-                'testSomething',
-            ],
-
-            [
-                [
-                    TEST_FILES_PATH . 'CoveredTrait.php' => range(14, 17),
-                ],
-                CoverageTraitMethodTest::class,
-                'testSomething',
-            ],
         ];
     }
 
