@@ -18,20 +18,15 @@ use PHPUnit\Framework\TestStatus\TestStatus;
 use PHPUnit\Framework\TestSuite;
 use PHPUnit\Runner\ResultCache\DefaultResultCache;
 use PHPUnit\TestFixture\MultiDependencyTest;
-use PHPUnit\TestFixture\TestWithDifferentSizes;
 use ReflectionClass;
 
 #[CoversClass(TestSuiteSorter::class)]
 #[Small]
 final class TestSuiteSorterTest extends TestCase
 {
-    /**
-     * Constants to improve clarity of @dataprovider.
-     */
-    private const IGNORE_DEPENDENCIES = false;
-
-    private const RESOLVE_DEPENDENCIES                = true;
-    private const MULTIDEPENDENCYTEST_EXECUTION_ORDER = [
+    private const IGNORE_DEPENDENCIES                   = false;
+    private const RESOLVE_DEPENDENCIES                  = true;
+    private const MULTI_DEPENDENCY_TEST_EXECUTION_ORDER = [
         MultiDependencyTest::class . '::testOne',
         MultiDependencyTest::class . '::testTwo',
         MultiDependencyTest::class . '::testThree',
@@ -140,14 +135,14 @@ final class TestSuiteSorterTest extends TestCase
     }
 
     /**
-     * A @dataprovider for basic execution reordering options based on MultiDependencyTest.
+     * A data provider for basic execution reordering options based on MultiDependencyTest.
      *
      * This class has the following relevant properties:
      *
-     * - it has five tests 'testOne' ... 'testFive'
-     * - 'testThree' @depends on both 'testOne' and 'testTwo'
-     * - 'testFour' @depends on 'MultiDependencyTest::testThree' to test FQN @depends
-     * - 'testFive' has no dependencies
+     * - it has five tests testOne, testTwo, testThree, testFour, testFive
+     * - testThree depends on testOne and testTwo
+     * - testFour depends on MultiDependencyTest::testThree
+     * - testFive has no dependencies
      */
     public static function commonSorterOptionsProvider(): array
     {
@@ -206,14 +201,14 @@ final class TestSuiteSorterTest extends TestCase
     }
 
     /**
-     * A @dataprovider for testing defects execution reordering options based on MultiDependencyTest.
+     * A data provider for testing defects execution reordering options based on MultiDependencyTest.
      *
      * This class has the following relevant properties:
      *
-     * - it has five tests 'testOne' ... 'testFive'
-     * - 'testThree' @depends on both 'testOne' and 'testTwo'
-     * - 'testFour' @depends on 'MultiDependencyTest::testThree' to test FQN @depends
-     * - 'testFive' has no dependencies
+     * - it has five tests testOne, testTwo, testThree, testFour, testFive
+     * - testThree depends on testOne and testTwo
+     * - testFour depends on MultiDependencyTest::testThree
+     * - testFive has no dependencies
      */
     public static function defectsSorterOptionsProvider(): array
     {
@@ -484,7 +479,7 @@ final class TestSuiteSorterTest extends TestCase
 
         $sorter->reorderTestsInSuite($suite, $order, $resolveDependencies, TestSuiteSorter::ORDER_DEFAULT);
 
-        $this->assertSame(self::MULTIDEPENDENCYTEST_EXECUTION_ORDER, $sorter->getOriginalExecutionOrder());
+        $this->assertSame(self::MULTI_DEPENDENCY_TEST_EXECUTION_ORDER, $sorter->getOriginalExecutionOrder());
         $this->assertSame($expectedOrder, $sorter->getExecutionOrder());
     }
 
@@ -590,26 +585,4 @@ final class TestSuiteSorterTest extends TestCase
 
         $this->assertSame($expected, $sorter->getExecutionOrder());
     }
-
-    public function testOrderBySize(): void
-    {
-        $suite = TestSuite::empty('test suite name');
-        $suite->addTestSuite(new ReflectionClass(TestWithDifferentSizes::class));
-        $sorter = new TestSuiteSorter;
-
-        $sorter->reorderTestsInSuite($suite, TestSuiteSorter::ORDER_SIZE, true, TestSuiteSorter::ORDER_DEFAULT);
-
-        $expectedOrder = [
-            TestWithDifferentSizes::class . '::testDataProviderWithSizeSmall with data set #0',
-            TestWithDifferentSizes::class . '::testDataProviderWithSizeSmall with data set #1',
-            TestWithDifferentSizes::class . '::testDataProviderWithSizeMedium with data set #0',
-            TestWithDifferentSizes::class . '::testDataProviderWithSizeMedium with data set #1',
-            TestWithDifferentSizes::class . '::testWithSizeMedium',
-            TestWithDifferentSizes::class . '::testWithSizeLarge',
-            TestWithDifferentSizes::class . '::testWithSizeSmall',
-            TestWithDifferentSizes::class . '::testWithSizeUnknown',
-        ];
-
-        $this->assertSame($expectedOrder, $sorter->getExecutionOrder());
-    }
 }
