@@ -21,6 +21,14 @@ use PHPUnit\Runner\TestSuiteSorter;
 #[TestDox('CLI Options Parser')]
 final class BuilderTest extends TestCase
 {
+    #[TestDox('argument')]
+    public function testArguments(): void
+    {
+        $configuration = (new Builder)->fromParameters(['command', 'argument']);
+
+        $this->assertSame(['argument'], $configuration->arguments());
+    }
+
     #[TestDox('--colors')]
     public function testColorsImplicitAuto(): void
     {
@@ -1235,6 +1243,26 @@ final class BuilderTest extends TestCase
         $configuration->stderr();
     }
 
+    #[TestDox('--fail-on-all-issues')]
+    public function testFailOnAllIssues(): void
+    {
+        $configuration = (new Builder)->fromParameters(['--fail-on-all-issues']);
+
+        $this->assertTrue($configuration->hasFailOnAllIssues());
+        $this->assertTrue($configuration->failOnAllIssues());
+    }
+
+    public function testFailOnAllIssuesMayNotBeConfigured(): void
+    {
+        $configuration = (new Builder)->fromParameters([]);
+
+        $this->assertFalse($configuration->hasFailOnAllIssues());
+
+        $this->expectException(Exception::class);
+
+        $configuration->failOnAllIssues();
+    }
+
     #[TestDox('--fail-on-deprecation')]
     public function testFailOnDeprecation(): void
     {
@@ -1422,6 +1450,10 @@ final class BuilderTest extends TestCase
 
         $this->assertTrue($configuration->hasStopOnDeprecation());
         $this->assertTrue($configuration->stopOnDeprecation());
+
+        $this->expectException(Exception::class);
+
+        $configuration->specificDeprecationToStopOn();
     }
 
     #[TestDox('--stop-on-deprecation=message')]
@@ -1626,6 +1658,26 @@ final class BuilderTest extends TestCase
         $configuration->testdoxPrinter();
     }
 
+    #[TestDox('--testdox-summary')]
+    public function testTestDoxPrinterSummary(): void
+    {
+        $configuration = (new Builder)->fromParameters(['--testdox-summary']);
+
+        $this->assertTrue($configuration->hasTestDoxPrinterSummary());
+        $this->assertTrue($configuration->testdoxPrinterSummary());
+    }
+
+    public function testTestDoxPrinterSummaryMayNotBeConfigured(): void
+    {
+        $configuration = (new Builder)->fromParameters([]);
+
+        $this->assertFalse($configuration->hasTestDoxPrinterSummary());
+
+        $this->expectException(Exception::class);
+
+        $configuration->testdoxPrinterSummary();
+    }
+
     #[TestDox('--testdox-html file')]
     public function testTestDoxHtml(): void
     {
@@ -1962,6 +2014,26 @@ final class BuilderTest extends TestCase
         $configuration->disallowTestOutput();
     }
 
+    #[TestDox('--display-all-issues')]
+    public function testDisplayAllIssues(): void
+    {
+        $configuration = (new Builder)->fromParameters(['--display-all-issues']);
+
+        $this->assertTrue($configuration->hasDisplayDetailsOnAllIssues());
+        $this->assertTrue($configuration->displayDetailsOnAllIssues());
+    }
+
+    public function testDisplayAllIssuesMayNotBeConfigured(): void
+    {
+        $configuration = (new Builder)->fromParameters([]);
+
+        $this->assertFalse($configuration->hasDisplayDetailsOnAllIssues());
+
+        $this->expectException(Exception::class);
+
+        $configuration->displayDetailsOnAllIssues();
+    }
+
     #[TestDox('--display-incomplete')]
     public function testDisplayIncomplete(): void
     {
@@ -2263,6 +2335,26 @@ final class BuilderTest extends TestCase
         $this->assertTrue($configuration->debug());
     }
 
+    #[TestDox('--extension')]
+    public function testExtension(): void
+    {
+        $configuration = (new Builder)->fromParameters(['--extension', 'ExtensionClass']);
+
+        $this->assertTrue($configuration->hasExtensions());
+        $this->assertSame(['ExtensionClass'], $configuration->extensions());
+    }
+
+    public function testExtensionMayNotBeConfigured(): void
+    {
+        $configuration = (new Builder)->fromParameters([]);
+
+        $this->assertFalse($configuration->hasExtensions());
+
+        $this->expectException(Exception::class);
+
+        $configuration->extensions();
+    }
+
     public function testInvalidOption(): void
     {
         $this->expectException(Exception::class);
